# -*- coding: utf-8 -*-
from django.conf import settings


DEFAULT_DEFAULT_TITLE = None
DEFAULT_DEFAULT_IMAGE = None
DEFAULT_DEFAULT_TYPE = None
DEFAULT_DEFAULT_LOCALE = settings.LANGUAGE_CODE
DEFAULT_DEFAULT_LOCALES = [l[0] for l in settings.LANGUAGES]


DEFAULT_TITLE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_TITLE', DEFAULT_DEFAULT_TITLE)
DEFAULT_IMAGE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_IMAGE', DEFAULT_DEFAULT_IMAGE)
DEFAULT_TYPE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_TYPE', DEFAULT_DEFAULT_TYPE)
DEFAULT_LOCALE = getattr(settings, 'SOCIAL_TAGS_DEFAULT_LOCALE', DEFAULT_DEFAULT_LOCALE)
DEFAULT_LOCALES = getattr(settings, 'SOCIAL_TAGS_DEFAULT_LOCALES', DEFAULT_DEFAULT_LOCALES)